==> zio-aws-auditmanager_2.13-5.17.125.1-sources.jar: zio/aws/auditmanager/model/RegisterOrganizationAdminAccountResponse.scala <==
package zio.aws.auditmanager.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.auditmanager.model.primitives.{OrganizationId, AccountId}
import scala.jdk.CollectionConverters._
final case class RegisterOrganizationAdminAccountResponse(
    adminAccountId: Option[AccountId] = None,
    organizationId: Option[OrganizationId] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.auditmanager.model.RegisterOrganizationAdminAccountResponse = {
    import RegisterOrganizationAdminAccountResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.auditmanager.model.RegisterOrganizationAdminAccountResponse
      .builder()
      .optionallyWith(
        adminAccountId.map(value => AccountId.unwrap(value): java.lang.String)
      )(_.adminAccountId)
      .optionallyWith(
        organizationId.map(value =>
          OrganizationId.unwrap(value): java.lang.String
        )
      )(_.organizationId)
      .build()
  }
  def asReadOnly
      : zio.aws.auditmanager.model.RegisterOrganizationAdminAccountResponse.ReadOnly =
    zio.aws.auditmanager.model.RegisterOrganizationAdminAccountResponse
      .wrap(buildAwsValue())
}
object RegisterOrganizationAdminAccountResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.auditmanager.model.RegisterOrganizationAdminAccountResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.auditmanager.model.RegisterOrganizationAdminAccountResponse =
      zio.aws.auditmanager.model.RegisterOrganizationAdminAccountResponse(
        adminAccountId.map(value => value),
        organizationId.map(value => value)
      )
    def adminAccountId: Option[AccountId]
    def organizationId: Option[OrganizationId]
    def getAdminAccountId: ZIO[Any, AwsError, AccountId] =
      AwsError.unwrapOptionField("adminAccountId", adminAccountId)
    def getOrganizationId: ZIO[Any, AwsError, OrganizationId] =
      AwsError.unwrapOptionField("organizationId", organizationId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.auditmanager.model.RegisterOrganizationAdminAccountResponse
  ) extends zio.aws.auditmanager.model.RegisterOrganizationAdminAccountResponse.ReadOnly {
    override val adminAccountId: Option[AccountId] = scala
      .Option(impl.adminAccountId())
      .map(value => zio.aws.auditmanager.model.primitives.AccountId(value))
    override val organizationId: Option[OrganizationId] = scala
      .Option(impl.organizationId())
      .map(value => zio.aws.auditmanager.model.primitives.OrganizationId(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.auditmanager.model.RegisterOrganizationAdminAccountResponse
  ): zio.aws.auditmanager.model.RegisterOrganizationAdminAccountResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-auditmanager_2.13-5.19.26.1-sources.jar: zio/aws/auditmanager/model/RegisterOrganizationAdminAccountResponse.scala <==
package zio.aws.auditmanager.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.auditmanager.model.primitives.{OrganizationId, AccountId}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class RegisterOrganizationAdminAccountResponse(
    adminAccountId: Optional[AccountId] = Optional.Absent,
    organizationId: Optional[OrganizationId] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.auditmanager.model.RegisterOrganizationAdminAccountResponse = {
    import RegisterOrganizationAdminAccountResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.auditmanager.model.RegisterOrganizationAdminAccountResponse
      .builder()
      .optionallyWith(
        adminAccountId.map(value => AccountId.unwrap(value): java.lang.String)
      )(_.adminAccountId)
      .optionallyWith(
        organizationId.map(value =>
          OrganizationId.unwrap(value): java.lang.String
        )
      )(_.organizationId)
      .build()
  }
  def asReadOnly
      : zio.aws.auditmanager.model.RegisterOrganizationAdminAccountResponse.ReadOnly =
    zio.aws.auditmanager.model.RegisterOrganizationAdminAccountResponse
      .wrap(buildAwsValue())
}
object RegisterOrganizationAdminAccountResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.auditmanager.model.RegisterOrganizationAdminAccountResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.auditmanager.model.RegisterOrganizationAdminAccountResponse =
      zio.aws.auditmanager.model.RegisterOrganizationAdminAccountResponse(
        adminAccountId.map(value => value),
        organizationId.map(value => value)
      )
    def adminAccountId: Optional[AccountId]
    def organizationId: Optional[OrganizationId]
    def getAdminAccountId: ZIO[Any, AwsError, AccountId] =
      AwsError.unwrapOptionField("adminAccountId", adminAccountId)
    def getOrganizationId: ZIO[Any, AwsError, OrganizationId] =
      AwsError.unwrapOptionField("organizationId", organizationId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.auditmanager.model.RegisterOrganizationAdminAccountResponse
  ) extends zio.aws.auditmanager.model.RegisterOrganizationAdminAccountResponse.ReadOnly {
    override val adminAccountId: Optional[AccountId] = zio.aws.core.internal
      .optionalFromNullable(impl.adminAccountId())
      .map(value => zio.aws.auditmanager.model.primitives.AccountId(value))
    override val organizationId: Optional[OrganizationId] =
      zio.aws.core.internal
        .optionalFromNullable(impl.organizationId())
        .map(value =>
          zio.aws.auditmanager.model.primitives.OrganizationId(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.auditmanager.model.RegisterOrganizationAdminAccountResponse
  ): zio.aws.auditmanager.model.RegisterOrganizationAdminAccountResponse.ReadOnly =
    new Wrapper(impl)
}
